Stan Math Library: stan/math/prim/scal/fun/divide.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
divide.hpp File Reference
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <cstddef>`
`#include <cstdlib>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
stan::return_type< T1, T2 >::type | stan::math::divide (const T1 &x, const T2 &y)
| Return the division of the first scalar by the second scalar. More...
int | stan::math::divide (const int x, const int y)

[ Stan Home Page ] © 2011–2016, Stan Development Team.